==> 1.0.1.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/web/gui/controladores/relatorios/RelatorioSapController.java <==
package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.CheckEvent;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Checkbox;
import org.zkoss.zul.Combobox;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.Messagebox;

import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.service.SapService;
import com.rjconsultores.ventaboletos.vo.integracao.FechamentoCntCorrenteVO;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxPuntoVenta;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderFechamentoCntcorrente;

@Controller("relatorioSapController")
@Scope("prototype")
public class RelatorioSapController extends MyGenericForwardComposer {

	private static final long serialVersionUID = -6110350409404675022L;

	private MyListbox boletoFechamentoList;
	
	private List<Empresa> lsEmpresas;
	private List<FechamentoCntCorrenteVO> lsFechamentoCntcorrente;
	private Empresa empresa;
	private PuntoVenta puntoVenta;
	private Boolean reenviar;
	private int qtdEnviar = 0;
	
	private Combobox cmbEmpresa;
	private MyComboboxPuntoVenta cmbPuntoVenta;
	private Datebox fecBoletoIni;
	private Datebox fecBoletoFin;
	private Checkbox chkReenviarGerados;
	
	@Autowired
	private EmpresaService empresaService;

	@Autowired
	private SapService sapService;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		this.lsEmpresas = empresaService.obtenerTodos();

        super.doAfterCompose(comp);
        
        for (Empresa e : this.lsEmpresas) {
			Comboitem comboItem = new Comboitem(e.getNombempresa());
			comboItem.setValue(e);
			comboItem.setParent(this.cmbEmpresa);
		}
        
        this.boletoFechamentoList.setItemRenderer(new RenderFechamentoCntcorrente(new EventListener() {

			@Override
			public void onEvent(Event arg0) throws Exception {

				FechamentoCntCorrenteVO registro = (FechamentoCntCorrenteVO) arg0.getTarget().getAttribute("data");
				for (Object obj : boletoFechamentoList.getListData()) {
					FechamentoCntCorrenteVO fechamento = (FechamentoCntCorrenteVO) obj;
					if (fechamento.equals(registro)) {
						fechamento.setEnviar( ((CheckEvent)arg0).isChecked() );
						
						if( ((CheckEvent)arg0).isChecked() ) {
							qtdEnviar++;
						}else {
							qtdEnviar--;
						}
						
						break;
					}
				}
			}
		}));
        
        this.chkReenviarGerados.setChecked(Boolean.FALSE);
        
	}
	
	public void onClick$btnPesquisar(Event ev) throws Exception {
		
		if(cmbEmpresa.getSelectedItem() == null){
			Messagebox.show(Labels.getLabel("relatorioSap.MGS.erroSemEmpresa"), Labels.getLabel("relatorioSap.window.title"), Messagebox.CANCEL, Messagebox.ERROR);
			return;
		}
		
		empresa = (Empresa) cmbEmpresa.getSelectedItem().getValue();
		
		if( cmbPuntoVenta.getSelectedItem() != null ) {
			puntoVenta = (PuntoVenta) cmbPuntoVenta.getSelectedItem().getValue();
		}

		this.lsFechamentoCntcorrente = sapService.obtenerTodosParaRemessa(empresa, this.fecBoletoIni.getValue(), this.fecBoletoFin.getValue(), chkReenviarGerados.isChecked(),  puntoVenta);
		this.boletoFechamentoList.setData(this.lsFechamentoCntcorrente);
		
		if(this.lsFechamentoCntcorrente.isEmpty()){
			Messagebox.show(Labels.getLabel("relatorioSapController.MGS.alertaCNABSemItens"), 
					Labels.getLabel("relatorioSap.window.title"), Messagebox.CANCEL, Messagebox.ERROR);
		}
	}
	
	public void onClick$btnExecutarRemessa(Event ev) throws Exception {
		
		if(this.lsFechamentoCntcorrente.isEmpty()){
			return;
		}
		try {
			int integrados = sapService.remessa( lsFechamentoCntcorrente );
			
			if( integrados == 0 ){
				
				Messagebox.show(Labels.getLabel("Registros no integrados"), 
								Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
					
				return;
			}else if( integrados < qtdEnviar ) {
				Messagebox.show("Alguns registros no foram integrados, favor filtrar novamente para verificar", 
						Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
			
				return;
			}else if( integrados == qtdEnviar ) {
				Messagebox.show("Todos registros foram integrados com sucesso", 
						Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
			
				return;
			}
		} catch (RuntimeException e) {
			Messagebox.show( e.getMessage(), 
					Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
		}
	}
	
	public Empresa getEmpresa() {
		return empresa;
	}
	
	public void setEmpresa(Empresa empresa) {
		this.empresa = empresa;
	}
	
	public Boolean getReenviar() {
		return reenviar;
	}
	
	public void setReenviar(Boolean reenviar) {
		this.reenviar = reenviar;
	}
}

==> 1.0.13.tar.gz: admmono/src/java/com/rjconsultores/ventaboletos/web/gui/controladores/relatorios/RelatorioSapController.java <==
package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.util.List;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.service.SapService;
import com.rjconsultores.ventaboletos.vo.integracao.FechamentoCntCorrenteVO;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxPuntoVenta;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderFechamentoCntcorrente;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.CheckEvent;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Checkbox;
import org.zkoss.zul.Combobox;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.Messagebox;

@Controller("relatorioSapController")
@Scope("prototype")
public class RelatorioSapController extends MyGenericForwardComposer {

	private static final long serialVersionUID = -6110350409404675022L;

	private MyListbox boletoFechamentoList;
	
	private List<Empresa> lsEmpresas;
	private List<FechamentoCntCorrenteVO> lsFechamentoCntcorrente;	
	private Empresa empresa;
	private PuntoVenta puntoVenta;
	private int qtdEnviar = 0;
	private String status;
	
	private Combobox cmbEmpresa;
	private MyComboboxPuntoVenta cmbPuntoVenta;
	private Datebox fecBoletoIni;
	private Datebox fecBoletoFin;
	
	private Checkbox chkIntegrado;
	private Checkbox chkNaoEnviado;
	private Checkbox chkPendente;
	private Checkbox chkRecusado;
	
	@Autowired
	private EmpresaService empresaService;

	@Autowired
	private SapService sapService;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		this.lsEmpresas = empresaService.obtenerTodos();

        super.doAfterCompose(comp);
        
        for (Empresa e : this.lsEmpresas) {
			Comboitem comboItem = new Comboitem(e.getNombempresa());
			comboItem.setValue(e);
			comboItem.setParent(this.cmbEmpresa);
		}
        
        this.boletoFechamentoList.setItemRenderer(new RenderFechamentoCntcorrente(new EventListener() {

			@Override
			public void onEvent(Event arg0) throws Exception {

				FechamentoCntCorrenteVO registro = (FechamentoCntCorrenteVO) arg0.getTarget().getAttribute("data");
				for (Object obj : boletoFechamentoList.getListData()) {
					FechamentoCntCorrenteVO fechamento = (FechamentoCntCorrenteVO) obj;
					if (fechamento.equals(registro)) {
						fechamento.setEnviar( ((CheckEvent)arg0).isChecked() );
						
						if( ((CheckEvent)arg0).isChecked() ) {
							qtdEnviar++;
						}else {
							qtdEnviar--;
						}
						
						break;
					}
				}
			}
		}));        
        
        this.chkIntegrado.setChecked(Boolean.FALSE);
        this.chkNaoEnviado.setChecked(Boolean.FALSE);
        this.chkPendente.setChecked(Boolean.FALSE);
        this.chkRecusado.setChecked(Boolean.FALSE);
        
	}
	
	public void onClick$btnPesquisar(Event ev) throws Exception {
		
		if(cmbEmpresa.getSelectedItem() == null){
			Messagebox.show(Labels.getLabel("relatorioSap.MGS.erroSemEmpresa"), Labels.getLabel("relatorioSap.window.title"), Messagebox.CANCEL, Messagebox.ERROR);
			return;
		}
		
		empresa = (Empresa) cmbEmpresa.getSelectedItem().getValue();
		
		if( cmbPuntoVenta.getSelectedItem() != null ) {
			puntoVenta = (PuntoVenta) cmbPuntoVenta.getSelectedItem().getValue();
		}
		
		status = "";
		status += chkIntegrado.isChecked()?"0,":"";
		status += chkNaoEnviado.isChecked()?"1,":"";
		status += chkPendente.isChecked()?"2,":"";
		status += chkRecusado.isChecked()?"3,":"";
		
		if(status.endsWith(",")) {
			status = status.substring(0, status.length()-1);
		}

		this.lsFechamentoCntcorrente = sapService.obtenerTodosParaRemessa(empresa, this.fecBoletoIni.getValue(), this.fecBoletoFin.getValue(), status,  puntoVenta);
		this.boletoFechamentoList.setData(this.lsFechamentoCntcorrente);
		
		if(this.lsFechamentoCntcorrente.isEmpty()){
			Messagebox.show(Labels.getLabel("relatorioSapController.MGS.alertaCNABSemItens"), 
					Labels.getLabel("relatorioSap.window.title"), Messagebox.CANCEL, Messagebox.ERROR);
		}
	}
	
	public void onClick$btnExecutarRemessa(Event ev) throws Exception {
		
		if(this.lsFechamentoCntcorrente.isEmpty()){
			return;
		}
		try {
			int integrados = sapService.remessa( lsFechamentoCntcorrente, true );
			
			if( integrados == 0 ){
				
				Messagebox.show(Labels.getLabel("Registros no integrados"), 
								Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
					
				return;
			}else if( integrados < qtdEnviar ) {
				Messagebox.show("Alguns registros no foram integrados, favor filtrar novamente para verificar", 
						Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
			
				return;
			}else if( integrados == qtdEnviar ) {
				Messagebox.show("Todos registros foram integrados com sucesso", 
						Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
			
				return;
			}
		} catch (RuntimeException e) {
			Messagebox.show( e.getMessage(), 
					Labels.getLabel("relatorioSap.window.title"), Messagebox.OK, Messagebox.ERROR);
		}
	}
	
	public Empresa getEmpresa() {
		return empresa;
	}
	
	public void setEmpresa(Empresa empresa) {
		this.empresa = empresa;
	}
}
